@@ -30,7 +30,6 @@ class Controller:
         self._library = Library()        
         self._window = Window(self._player, self._config, self._library)
         self._banner = None
-        self._scrobbler = None
     
         # programm
         program = hildon.Program()
@@ -40,7 +39,9 @@ class Controller:
         gobject.set_application_name("YouAmp")
    
         # last.fm submission
-        self._scrobbler = scrobbler.Scrobbler(self._config["lastfm-user"], self._config["lastfm-pass"], ("you", VERSION))
+        self._scrobbler = scrobbler.Scrobbler()
+        self._scrobbler.connect("error", lambda c, t, m: sys.stderr.write(m+"\n"))
+        self._scrobbler.login(self._config["lastfm-user"], self._config["lastfm-pass"], ("you", VERSION))
             
         # RPC
         if IS_MAEMO:
@@ -186,7 +187,7 @@ class Controller:
     def quit(self, caller=None):        
         if self._scrobbler.is_connected():
             try:
-                self._scrobbler.flush()
+                print self._scrobbler.flush()
             except urllib2.URLError, e:
                 sys.stderr.write("lastfm.submit: %s\n" % e)
         
