@@ -20,7 +20,7 @@ class Controls(gtk.HBox):
         play_img_copy = gtk.image_new_from_pixbuf(self._play_img.get_pixbuf())
         toggle.set_image(play_img_copy)
         toggle.set_size_request(60, -1)
-        toggle.connect("clicked", self.on_toggle)
+        toggle.connect("clicked", lambda caller: self._player.toggle())
         self.toggle_button = toggle
         self.pack_start(toggle, expand=False)
         
@@ -59,19 +59,15 @@ class Controls(gtk.HBox):
         
         self._config.notify_add("volume", self._on_conf_volume_changed)
         self._config.notify_add("search-str", lambda *args: self.toggle_button.grab_focus())
-        self._player.connect("song-changed", self._update_toggle_img)
         self._player.connect("seek-changed", lambda caller, new_seek: self.pos.set_value(new_seek))
-    
-    def _update_toggle_img(self, *args):                
+        self._player.connect("toggled", self._update_toggle_img)
+
+    def _update_toggle_img(self, caller, playing):                
         # FIXME copying image for maemo
-        if self._player.playing:
+        if playing:
             self.toggle_button.set_image(gtk.image_new_from_pixbuf(self._pause_img.get_pixbuf()))
         else:
             self.toggle_button.set_image(gtk.image_new_from_pixbuf(self._play_img.get_pixbuf()))
-        
-    def on_toggle(self, caller=None):
-        self._player.toggle()
-        self._update_toggle_img()
 
     def on_seek(self, caller, scroll, value):
         self._player.seek_to(caller.get_value())
