@@ -2,6 +2,8 @@ import gtk
 import gtk.gdk
 import md5
 
+from youamp import VERSION
+
 class PrefLabel(gtk.Label):
     def __init__(self, txt):
         gtk.Label.__init__(self)
@@ -23,6 +25,8 @@ class Preferences(gtk.Window):
     def _create(self, parent, config, scrobbler):
         gtk.Window.__init__(self)
         self.config = config
+        self._scrobbler = scrobbler
+        self._scrobbler.connect("error", self._update_lfm_state)
         
         self.set_title(_("Preferences"))
         self.set_transient_for(parent)
@@ -86,7 +90,7 @@ class Preferences(gtk.Window):
         
         user_entry = gtk.Entry()
         user_entry.set_text(self.config["lastfm-user"])
-        user_entry.connect("changed", self._on_lfm_user_changed)
+        user_entry.connect("focus-out-event", self._on_lfm_user_changed)
         login.attach(user_entry, 1, 2, 0, 1, xoptions=0)
 
         pass_label = gtk.Label(_("Password"))
@@ -96,7 +100,7 @@ class Preferences(gtk.Window):
         pass_entry = gtk.Entry()
         pass_entry.set_visibility(False)
         pass_entry.set_text("******" if self.config["lastfm-pass"] != "" else "")
-        pass_entry.connect("changed", self._on_lfm_pass_changed)
+        pass_entry.connect("focus-out-event", self._on_lfm_pass_changed)
         login.attach(pass_entry, 1, 2, 1, 2, xoptions=0)
 
         status_label = PrefLabel(_("Status"))
@@ -125,11 +129,35 @@ class Preferences(gtk.Window):
         self.connect("delete-event", self.hide_on_delete)
         self.show_all()
     
-    def _on_lfm_user_changed(self, caller):
-        self.config["lastfm-user"] = caller.get_text()
+    def _update_lfm_state(self, caller, e, msg):
+        if msg == "BADAUTH":
+            state = _("Wrong login data")
+        else:
+            state = _("Disconnected")
+        
+        self._lastfm_state.set_text(state)
+    
+    def _try_login(self):
+        self._scrobbler.login(self.config["lastfm-user"], self.config["lastfm-pass"], ("you", VERSION))
+        self._lastfm_state.set_text(_("Connected"))
+            
+    def _on_lfm_user_changed(self, caller, ev):
+        txt = caller.get_text()
+        
+        if self.config["lastfm-user"] == txt:
+            return
+        
+        self.config["lastfm-user"] = txt
+        self._try_login()
 
-    def _on_lfm_pass_changed(self, caller):
-        self.config["lastfm-pass"] = md5.md5(caller.get_text()).hexdigest()
+    def _on_lfm_pass_changed(self, caller, ev):
+        txt = caller.get_text()
+        
+        if txt == "******":
+            return
+
+        self.config["lastfm-pass"] = md5.md5(txt).hexdigest()
+        self._try_login()
  
     def _on_mf_changed(self, caller):
         self.config["music-folder"] = caller.get_current_folder()
